@@ -27,13 +27,16 @@ var image_cropping = {
           min_width = $this.data('width'),
           min_height = $this.data('height');
 
+      var is_image_portrait = (org_height > org_width);
+      var is_select_portrait = (min_height > min_width);
+
       if ($this.data('adapt-rotation') == true) {
-        if ($image.get(0).width < $image.get(0).height) {
-          // cropping height/width need to be switched, picture is in portrait mode
-          var x = min_width;
-          min_width = min_height;
-          min_height = x;
-        }
+          if (is_image_portrait != is_select_portrait) {
+              // cropping height/width need to be switched, picture is in portrait mode
+              var x = min_width;
+              min_width = min_height;
+              min_height = x;
+          }
       }
 
       var $image = image_cropping.$('<img>', {
@@ -73,11 +76,13 @@ var image_cropping = {
       // hide the input field, show image to crop instead
       $this.hide().after($image);
 
-      image_cropping.$('#' + image_id).Jcrop(options, function(){jcrop=this;});
+      var jcrop = {};
+
+      image_cropping.$('#' + image_id).Jcrop(options, function(){jcrop[image_id]=this;});
 
       if ($this.data('allow-fullsize') == true) {
         if(cropping_disabled){
-          jcrop.release();
+          jcrop[image_id].release();
           $this.val('-'+$this.val());
         }
         var label = 'allow-fullsize-'+image_id;
@@ -88,11 +93,11 @@ var image_cropping = {
         image_cropping.$('#'+label).click(function(){
           if (cropping_disabled==true){
             $this.val($this.val().substr(1));
-            jcrop.setSelect($this.val().split(','));
+            jcrop[image_id].setSelect($this.val().split(','));
             cropping_disabled = false;
           } else {
             $this.val('-'+$this.val());
-            jcrop.release();
+            jcrop[image_id].release();
             cropping_disabled = true;
           }
         });
